# Build an app

At this point you should have [set up your environment and installed Panel](installation.md) and been introduced some of the basic ideas and APIs behind Panel in the [Core Concepts](core_concepts.md) guide.

However the easiest way to get started with Panel is to play around with it yourself. In this section we're going to be building a basic application using a public dataset and add some interactivity. The easiest way to follow along is to copy the examples and launch a Jupyter notebook session as described in the [installation guide](installation.md).

:::{important}
This guide is written for an interactive environment such as Jupyter notebooks. The interactive widgets will not work in a static version of this documentation.
:::

```{eval-rst}
..  notebook:: panel ../../examples/getting_started/Build_Apps.ipynb
```
